@@ -4,8 +4,8 @@ from ...plugin import Plugin
 
 
 class GithubPlugin(Plugin):
-    name = "github"
-    profile = {
+    identity = "github"
+    validity = {
         "type": "object",
         "required": ["user", "repo"],
         "properties": {
@@ -14,41 +14,43 @@ class GithubPlugin(Plugin):
         },
     }
 
+    def __init__(self, document):
+        super().__init__(document)
+
+        # Infer data
+        try:
+            repo = Repo()
+            pack = parse(repo.remote().url)
+            self.__data = {"user": pack.owner, "repo": pack.repo}
+        except Exception:
+            self.__data = {}
+
     # Context
 
-    @Plugin.property
+    @property
     def user(self):
-        return self.config.get("user", self.parsed_data.get("user"))
+        return self.config.get("user", self.__data.get("user"))
 
-    @Plugin.property
+    @property
     def repo(self):
-        return self.config.get("repo", self.parsed_data.get("repo"))
+        return self.config.get("repo", self.__data.get("repo"))
 
-    @Plugin.property
+    @property
     def base_url(self):
         if self.user and self.repo:
             return f"https://github.com/{self.user}/{self.repo}"
 
-    @Plugin.property
+    @property
     def report_url(self):
         if self.base_url:
             return f"{self.base_url}/issues"
 
-    @Plugin.property
+    @property
     def fork_url(self):
         if self.base_url:
             return f"{self.base_url}/fork"
 
-    @Plugin.property
+    @property
     def edit_url(self):
         if self.base_url:
             return f"{self.base_url}/edit/main/{self.document.source}"
-
-    @Plugin.property
-    def parsed_data(self):
-        try:
-            repo = Repo()
-            pack = parse(repo.remote().url)
-            return {"user": pack.owner, "repo": pack.repo}
-        except Exception:
-            return {}
