@@ -1,3 +1,4 @@
+import json
 import yaml
 from ...plugin import Plugin
 from frictionless import Report
@@ -18,8 +19,11 @@ class ReportPlugin(Plugin):
 
     def process_snippet(self, snippet):
         if self.document.format == "html":
-            if snippet.type == "report" and snippet.lang == "yaml":
-                spec = yaml.safe_load(str(snippet.input).strip())
+            if snippet.type == "report" and snippet.lang in ["yaml", "json"]:
+                if snippet.lang == "yaml":
+                    spec = yaml.safe_load(str(snippet.input).strip())
+                if snippet.lang == "json":
+                    spec = json.loads(str(snippet.input).strip())
                 spec = Report(**spec).to_dict()
                 self.__count += 1
                 report = {"spec": spec, "elem": f"livemark-report-{self.__count}"}
