@@ -23,15 +23,20 @@ class TablePlugin(Plugin):
                 spec["licenseKey"] = "non-commercial-and-evaluation"
                 detector = Detector(field_float_numbers=True)
                 with Resource(spec.get("data", []), detector=detector) as resource:
-                    # TODO: export as a dict not list?
                     header, *lists = resource.to_snap(json=True)
                 spec.setdefault("colHeaders", header)
                 spec["data"] = lists
                 spec = json.dumps(spec, ensure_ascii=False)
                 spec = spec.replace("'", "\\'")
                 self.__count += 1
-                table = {"spec": spec, "elem": f"livemark-table-{self.__count}"}
-                snippet.output = self.read_asset("markup.html", table=table) + "\n"
+                card = snippet.props.get("card")
+                elem = f"livemark-table-{self.__count}"
+                if card:
+                    elem += "-card"
+                table = {"spec": spec, "elem": elem}
+                snippet.output = (
+                    self.read_asset("markup.html", card=card, table=table) + "\n"
+                )
 
     def process_markup(self, markup):
         if self.__count:
